# sk_arc_list_entities.py
#
# This script lists the names, types, and record counts of the features and tables found in
# an ArcGIS workspace, e.g., shapefile folder, geodatabase, etc.
#
# There are 2 variables that require values: the name of the workspace and the name of the
# .csv file. In the example below the workspace is a shapfile folder named C:\skdata\st_louis
# of US census TIGER data and the .csv file is saved in a file named C:\sktools\st_louis_ent.csv
#
# The intent here is to generate a .csv file that can be easily viewed, e.g., with MS Excel and/or
# imported into an ArcGIS workspace as a metadata table.
#
# www.scribekey.com 10/6/2014

import arcpy
from arcpy import env
import os

env.workspace = r"C:\st_louis"

file = open(r"C:\sk_tools\st_louis_entities.csv", "w")

file.write("OBJECTID,ENTITY_NM,ENT_TYPE,NUM_ROWS\n")

i = 0

try:    
    featureList = arcpy.ListFeatureClasses()
    for feature_class in featureList:
        i = i + 1
        print "feature_class: " + feature_class
        count = str(arcpy.GetCount_management(feature_class))
        print "count: " + count 
        feature_description = arcpy.Describe(feature_class)
        print "type: " + feature_description.shapeType
        file.write(str(i) + "," + feature_class + "," +  feature_description.shapeType + "," + count + "\n")

    tableList = arcpy.ListTables()
    for table in tableList:
        print "table: " + table
        if not table.endswith(".dbf"):
            continue
        i = i + 1
        count = str(arcpy.GetCount_management(table))
        print "count: " + count
        file.write(str(i) + "," + table + "," + "Table" + "," + count + "\n")

except:
    file.close()
    
file.close()
del env

