# sk_arc_list_fields.py
#
# This script lists the names, data types, and data lengths of the fields for the features
# and tables found in an ArcGIS workspace, e.g., shapefile folder, geodatabase, etc.
#
# There are 2 variables that require values: the name of the workspace and the name of the
# .csv file. In the example below the workspace is a shapfile folder named C:\skdata\st_louis
# of US census TIGER data and the .csv file is saved in a file named C:\sktools\st_louis_att.csv
#
# The intent here is to generate a .csv file that can be easily viewed, e.g., with MS Excel and/or
# imported into an ArcGIS workspace as a metadata table.
#
# www.scribekey.com 10/6/2014

import arcpy
from arcpy import env
import os

try: 
    env.workspace = r"C:\st_louis"

    file = open(r"C:\sk_tools\st_louis_fields.csv", "w")

    file.write("OBJECTID,ENTITY_NM,FIELD_NM,DATA_TYPE,DATA_LEN\n")

    i = 0

    entityList = arcpy.ListFeatureClasses()
    for entity in entityList:
        print entity
        fields = arcpy.ListFields(entity)
        for field in fields:
            i = i + 1
            file.write(str(i) + "," + entity + "," + field.name + "," +  field.type + "," + str(field.length) + "\n")

    entityList = arcpy.ListTables()
    for entity in entityList:
        print entity
        fields = arcpy.ListFields(entity)
        for field in fields:
            i = i + 1
            file.write(str(i) + "," + entity + "," + field.name + "," +  field.type + "," + str(field.length) + "\n")

except:
    file.close()
    
file.close()
del env





