# sk_arc_xy_csv_to_points.py
#
# This script converts a .csv file with x,y fields into an ArcGIS feature class
#
# There are several hard coded variables to use for configuring this tool.
#
# xy_table_file: the full path of the input csv text file with x,y fields
# output_features_name: the name of the new features to be created
# workspace_name: the full path of the ArcGIS workspace, e.g., shapefile folder or geodb
# spatial_ref_key: the unique id for the spatial reference used for the output features
# empty_mxd_file_name: an .mxd file required for processing
# www.scribekey.com 10/6/2014

import arcpy
import arcgisscripting

# args/settings: input csv table with x y, mdb or workspace, fc_name
xy_table_file = r"C:\sk_tools\lm_pnts_chg.csv"

# workspace_name = r"C:\sktools"
workspace_name = r"C:\sk_tools\sk_data_change_test_geodb.mdb"

# if shapefile was desired output 
# workspace_name = r"C:\sktools"

output_features_name = "lm_chg_pnts"

empty_mxd_file_name = r"C:\sk_tools\empty.mxd"

# note this is spatial ref key for WGS 84 lon/lat
spatial_ref_key = 4326

print "Getting mxd ..."
mxd = arcpy.mapping.MapDocument(empty_mxd_file_name)

print "Getting data frame ..."
df = arcpy.mapping.ListDataFrames(mxd, "*")[0]

print "Getting xy data file/table ..."
xy_table = arcpy.mapping.TableView(xy_table_file)

print "Adding table to mxd ..."
arcpy.mapping.AddTableView(df, xy_table)

# GCS_WGS_1984
print "Setting spatial reference ..."
spatialRef = arcpy.SpatialReference(spatial_ref_key)

print "Creating xy event layer ..."
# make mdb, csv_file, output_features args or easy to set up front
arcpy.MakeXYEventLayer_management(xy_table, "X", "Y", output_features_name, spatialRef, "")

print "Creating scripting object ..."
gp = arcgisscripting.create()

# tbd use mdb instead of shape
print "Getting output workspace ..."
gp.Workspace = workspace_name

# note: even though the function is called FeatureClassToShapeFile, it also writes to geodbs.
print "Exporting xy event layer to output features ..."
gp.FeatureClassToShapefile (output_features_name, gp.Workspace)

del mxd

